formula_mapper = {
    "Cyclopropane": "C3H6",
    "Pentane": "C5H12",
    "Kapton": "C22H10N2O5",
    "Mylar": "C10H8O4",
    "Polypropylene": "C3H6",
    "Butane": "C4H10",
    "Polystyrene": "C8H8",
    "Acetylene": "C2H2",
    "Polyvinyltoluene": "C9H10",
    "C amorphous": "C",
    "Methane": "NH3",
    "Hydroxy apatite": "Ca5P3O13H",
    "H2O solid": "H2O",
    "H2o liq": "H2O",
    "H2O vapor": "H2O",
    "acetylene": "C2H2",
    "Ethylene": "C2H4",
    "Cyclopropane": "C3H6",
    "Pentane": "C5H12",
    "Kapton": "C22H10N2O5",
    "Mylar": "C10H8O4",
    "Polypropylene": "C3H6",
    "Propylene": "C3H6",
    "Butane": "C4H10",
    "Polysterene": "C8H8",
    "Acetylene": "C2H2",
    "Polyvinyltoluene": "C9H10",
    "C amorphous": "C",
    "Methane": "NH3",
    "Hydroxy apatite": "Ca5P3O13H",
    "H2O solid": "H2O",
    "H2o liq": "H2O",
    "H2O vapor": "H2O",
    "acetylene": "C2H2",
    "heptane": "C7H16",
    "Pentane": "C5H12",
    "ethane": "C2H6",
    "Polysulfone": "C6H4SO2",
    "Methyl alcohol liquid, vapor": "CH4O",
    "Propyl alcohol liquid, vapor": "C3H8O",
    "Propyl alcohol vapor": "C3H8O",
    "Propylene oxide vapor": "C3H6O",
    "Cyclohexane liquid, vapor": "C6H12",
    "Graphite Oxide": "C5O5",
    "Ethyl alcohol liquid, vapor": "C2H6O",
    "Ethyl alcohol liquid": "C2H6O",
    "Ethane": "C2H6",
    "Polycarbonate": "C15H16O2",
    "Pentane liquid, vapor": "C5H12",
    "Hexane liquid, vapor": "C6H14",
    "Heptane liquid, vapor": "C7H16",
    "Propane": "C3H8",
    "Ethylene": "C2H4",
    "Polyethylene": "C2H4",
    "Havar": "Co",
    "c3f8": "C3F8",
    "Cyclopropane": "C3H6",
    "Pentane": "C5H12",
    "Kapton": "C22H10N2O5",
    "Mylar": "C10H8O4",
    "Polypropylene": "C3H6",
    "Butane": "C4H10",
    "Polystyrene": "C8H8",
    "Acetylene": "C2H2",
    "Polyvinyltoluene": "C9H10",
    "C amorphous": "C",
    "Methane": "NH3",
    "Hydroxy apatite": "Ca5P3O13H",
    "H2O solid": "H2O",
    "H2o liq": "H2O",
    "H2O vapor": "H2O",
    "acetylene": "C2H2",
    "Ethylene": "C2H4",
    "Cyclopropane": "C3H6",
    "Pentane": "C5H12",
    "Kapton": "C22H10N2O5",
    "Mylar": "C10H8O4",
    "Polypropylene": "C3H6",
    "Propylene": "C3H6",
    "Butane": "C4H10",
    "Polysterene": "C8H8",
    "Acetylene": "C2H2",
    "Polyvinyltoluene": "C9H10",
    "C amorphous": "C",
    "Methane": "NH3",
    "Hydroxy apatite": "Ca5P3O13H",
    "H2O solid": "H2O",
    "H2o liq": "H2O",
    "H2O vapor": "H2O",
    "acetylene": "C2H2",
    "heptane": "C7H16",
    "Pentane": "C5H12",
    "ethane": "C2H6",
    "Polysulfone": "C6H4SO2",
    "Methyl alcohol liquid, vapor": "CH4O",
    "Propyl alcohol liquid, vapor": "C3H8O",
    "Propyl alcohol vapor": "C3H8O",
    "Propylene oxide vapor": "C3H6O",
    "Cyclohexane liquid, vapor": "C6H12",
    "Graphite Oxide": "C5O5",
    "Ethyl alcohol liquid, vapor": "C2H6O",
    "Ethyl alcohol liquid": "C2H6O",
    "Ethane": "C2H6",
    "Polycarbonate": "C15H16O2",
    "Pentane liquid, vapor": "C5H12",
    "Hexane liquid, vapor": "C6H14",
    "Heptane liquid, vapor": "C7H16",
    "Propane": "C3H8",
    "Ethylene": "C2H4",
    "Polyethylene": "C2H4",
    "c6h6v": "C6H6",
    "vmet": "CH5N",
    "Methylamine": "CH5N",
    "etam": "C2H7N",
    "Ethylamine": "C2H7N",
    "ch3br": "CH3Br",
    "tmam": "C3H9N",
    "Trimethylamine": "C3H9N",
    "mam": "Methylamine",
    "Silicon nitride": "Si3N4",
    "br": "Br",
    "c3h8": "C3H8",
    "xev": "Xe",
    "baf2": "BaF2",
    "c4f8": "C4F8",
    "so2": "SO2",
    "sr": "Sr",
    "ch4": "CH4",
    "detev": "C4H10O",
    "Diethyl ether": "C4H10O",
    "Dimethyl ether": "C2H6O",
    "dmam": "C2H7N",
    "Dimethyl amine": "C2H7N",
    "cs": "Cs",
    "cd": "Cd",
    "cyhev": "C6H12",
    "Cyclohexane": "C6H12",
    "cycpr": "C3H6",
    "Cyclopropane": "C3H6",
    "rh": "Rh",
    "prpsv": "C3H6S",
    "Propylene sulfide": "C3H6S",
    "cs2v": "CS2",
    # "cs2v": "Carbon disulfide",
    "ch5br": "CH5Br",
    "ethsv": "C4H10S",
    "Ethyl sulfide": "C4H10S",
    "ccl2f": "CCl2F",
    "nd": "Nd",
    "cf3h": "CF3H",
    "pntov": "C5H10O",
    "3-Pentanone": "C5H10O",
    "3-Pentanone vapor": " C5H10O",
    "ccl4v": "CCl4",
    "xev": "Xe",
    "ethcl": "C2H5Cl",
    "EthylChloride": "C2H5Cl",
    "bacl2": "BaCl2",
    "zro2": "ZrO2",
    "l115": "LR-115",
    "cr39": "CR-39",
    "Ar solid": "Ar",
    "Hexane": "C6H14",
    "Octane": "C8H18",
    "Allene": "C3H4",
    "tefl": "C2F4",
    "c3f8": "C3F8",
    "Silicon Nitride": "Si3N4",
    "ars": "Ars",
    "inp": "InP",
    "CR-39": "C12H18O7",
    "caf2": "CaF2",
    "al2O3": "Al2O3",
    "n2o": "N2O",
    "Havar": "Co",
    "Diamond": "C",
    "Graphite": "C",
    "Al2o3": "Al2O3",
    "znte": "ZnTe",
    "inp": "InP",
    "c2brf": "C2BrF",
    "c2h3f": "C2H3Bf",
    "c2h3l": "C2H3",
    "c3f8": "C3F8",
    "c3h8": "C3H8",
    "c4f8": "C4F8",
    "c6h6v": "C6H6",
    "cbrf3": "CBrF3",
    "cclf3": "CClF3",
    "cdte": "CdTe",
    "cf2l2": "CF2Cl2",
    "cf3br": "CF3Br",
    "ch4": "CH4",
    "chclf": "CHClF",
    "Propylene": "C3H6",
    "Teflon": "C2F4",
    "Pentene": "C5H10",
    "Acetaldehyde": "C2H4O",
    "Acetone": "C3H6O",
    "C diamond": "C",
    "CCl4 liquid, vapor": "CCl4",
    "Dimethyl sulfite vapor": "C2H6O3S",
    "Dimethylamine": "C2H6NH",
    "Dimethyldisulfide vapor": "C2H6S2",
    "Dimethylsulfide vapor": "C2H6S",
    # 'Ethynylbenzene vapor',
    # 'Inp': 'InP',
    # 'LR-115',
    # 'NE-111',
    # 'P-dioxane': 'C4H8O2',
    # 'Pliolite',
    # 'Toluene',
    # 'c2h3f': 'C2H3F',
    # 'ce': 'Ce',
    # 'cl':'Cl',
    # 'clfm',
    # 'clfmv', 'co2c', 'cychv', 'cycov', 'cyhdv', 'cyhov', 'dclm',
    # 'dclmv', 'dfley', 'ealc', 'ealcv', 'etho', 'ethyl', 'form'
    # 'Vyns', 'air', 'alle',
    # 'btadv', 'but', 'butov', 'buty', 'c2h3f', 'ce', 'cl', 'clfm',
    # 'clfmv', 'co2c', 'cychv', 'cycov', 'cyhdv', 'cyhov', 'dclm',
    # 'dclmv', 'dfley', 'ealc', 'ealcv', 'etho', 'ethyl', 'form',
    # 'hptyv', 'mumet', 'phb', 'polys', 'pr', 'propy', 're', 'thphv',
    # 'tmsv
}
